[][src]Module tarantool_module::fiber

Modules

ffi

Structs

Cond

Conditional variable for cooperative multitasking (fibers).

Fiber

Contains information about fiber

FiberAttr

Fiber attributes container

Functions

clock

Report loop begin time as double (cheap). Uses monotonic clock.

clock64

Report loop begin time as 64-bit int. Uses monotonic clock.

fiber_yield

Return control to another fiber and wait until it'll be woken.

is_cancelled

Check current fiber for cancellation (it must be checked manually).

reschedule

Reschedule fiber to end of event loop cycle.

set_cancellable

Make it possible or not possible to wakeup the current fiber immediately when it's cancelled.

sleep

Put the current fiber to sleep for at least time seconds.

time

Report loop begin time as double (cheap).

time64

Report loop begin time as 64-bit int.