[−][src]Function tarantool_module::fiber::fiber_yield
pub fn fiber_yield()
Return control to another fiber and wait until it'll be woken.
See also: Fiber::wakeup
pub fn fiber_yield()
Return control to another fiber and wait until it'll be woken.
See also: Fiber::wakeup