[−][src]Function tarantool_module::fiber::sleep
pub fn sleep(time: f64)
Put the current fiber to sleep for at least time seconds.
time- time to sleep
Note: this is a cancellation point (See also: is_cancelled)
pub fn sleep(time: f64)
Put the current fiber to sleep for at least time seconds.
time - time to sleepNote: this is a cancellation point (See also: is_cancelled)