[−][src]Module tarantool_module::index
Modules
| c_api |
Structs
| Index | |
| IndexIterator |
Enums
| IteratorType | Controls how to iterate over tuples in an index.
Different index types support different iterator types.
For example, one can start iteration from a particular value
(request key) and then retrieve all tuples where keys are
greater or equal (= |