[−][src]Module tarantool_module::tuple
Modules
| ffi |
Structs
| FunctionArgs | |
| FunctionCtx | |
| KeyDef | |
| KeyDefItem | |
| Tuple | |
| TupleFormat | Tuple Format. |
| TupleIterator | Tuple iterator |
Enums
| FieldType | |
| TupleBuffer |
Traits
| AsTuple | Must be implemented for types, which will be used with box access methods as data |
Functions
| session_push | Push MessagePack data into a session data channel - socket,
console or whatever is behind the session. Note, that
successful push does not guarantee delivery in case it was sent
into the network. Just like with |