[−][src]Struct tarantool_module::tuple::KeyDef
Implementations
impl KeyDef[src]
pub fn new(items: Vec<KeyDefItem>) -> Self[src]
Create key definition with key fields with passed typed on passed positions. May be used for tuple format creation and/or tuple comparison.
items- array with key field identifiers and key field types (see FieldType)
pub fn compare(&self, tuple_a: &Tuple, tuple_b: &Tuple) -> Ordering[src]
Compare tuples using the key definition.
tuple_a- first tupletuple_b- second tuple
Returns:
Ordering::Equalifkey_fields(tuple_a) == key_fields(tuple_b)Ordering::Lessifkey_fields(tuple_a) < key_fields(tuple_b)Ordering::Greaterifkey_fields(tuple_a) > key_fields(tuple_b)
pub fn compare_with_key<K>(&self, tuple: &Tuple, key: &K) -> Ordering where
K: AsTuple, [src]
K: AsTuple,
Compare tuple with key using the key definition.
tuple- tuplekey- key with MessagePack array header
Returns:
Ordering::Equalifkey_fields(tuple) == parts(key)Ordering::Lessifkey_fields(tuple) < parts(key)Ordering::Greaterifkey_fields(tuple) > parts(key)